export var __esModule: boolean;
export default Scene;
/**
 * A scene.
 *
 * Every scene has its own list of model instances, and its own camera and viewport.
 *
 * In addition, every scene may have its own AudioContext if enableAudio() is called.
 * If audio is enabled, the AudioContext's listener's location will be updated automatically.
 * Note that due to browser policies, this may be done only after user interaction with the web page.
 */
declare class Scene {
    constructor(viewer: any);
    camera: camera_1.default;
    grid: grid_1.default;
    visibleCells: number;
    visibleInstances: number;
    updatedParticles: number;
    audioEnabled: boolean;
    audioContext: AudioContext | null;
    instances: any[];
    emittedObjectUpdater: emittedobjectupdater_1.default;
    /**
     * Similar to WebGL's own `alpha` parameter.
     *
     * If false, the scene will be cleared before rendering, meaning that scenes behind it won't be visible through it.
     *
     * If true, alpha works as usual.
     */
    alpha: boolean;
    /**
     * The scene's background color.
     *
     * Only used if `alpha` is false.
     */
    color: gl_matrix_1.vec3;
    /**
     * The area on the canvas in which this scene is rendered.
     *
     * Defaults to the entire canvas.
     *
     * The vector defines [x, y, width, height], sizes are in pixels, and everything is related to the bottom left corner of the canvas.
     */
    viewport: gl_matrix_1.vec4;
    /**
     * The position of the light that is used when rendering.
     *
     * Affects HD MDX and M3 models.
     */
    lightPosition: gl_matrix_1.vec3;
    viewer: any;
    /**
     * Creates an AudioContext if one wasn't created already, and resumes it if needed.
     *
     * The returned promise will resolve to whether it is actually running or not.
     *
     * It may stay in suspended state indefinitly until the user interacts with the page, due to browser policies.
     */
    enableAudio(): Promise<boolean>;
    /**
     * Suspend the audio context.
     */
    disableAudio(): void;
    /**
     * Sets the scene of the given instance.
     *
     * Equivalent to instance.setScene(scene).
     */
    addInstance(instance: any): boolean;
    /**
     * Remove the given instance from this scene.
     *
     * Equivalent to ModelInstance.detach().
     */
    removeInstance(instance: any): boolean;
    /**
     * Clear this scene.
     */
    clear(): void;
    /**
     * Detach this scene from the viewer.
     *
     * Equivalent to viewer.removeScene(scene).
     */
    detach(): any;
    /**
     * Update this scene.
     */
    update(dt: any): void;
    renderInstance(instance: any): void;
    /**
     * Use the scene's viewport.
     *
     * Should be called before `renderOpaque()` and `renderTranslucent()`.
     *
     * Called automatically by `render()`.
     */
    startFrame(): void;
    /**
     * Render opaque things in this scene.
     *
     * They are rendered front to back.
     */
    renderOpaque(): void;
    /**
     * Renders translucent things in this scene.
     *
     * They are rendered back to front.
     */
    renderTranslucent(): void;
    /**
     * Render this scene.
     */
    render(): void;
    /**
     * Clear all of the emitted objects in this scene.
     */
    clearEmittedObjects(): void;
}
import camera_1 = require("./camera");
import grid_1 = require("./grid");
import emittedobjectupdater_1 = require("./emittedobjectupdater");
import gl_matrix_1 = require("gl-matrix");
